import { Text, View } from '@tarojs/components'
import { memo, useCallback, useEffect, useMemo, useState } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import { formatPriceDiv } from '@/common/format'
import Taro from '@tarojs/taro'
import LayoutBlock from '@/components/layoutBlock'
import MCheckbox from '@/components/checkbox'
import Tag from '@/components/tag'
import Divider from '@/components/divider'
import NormalButton from '@/components/normalButton'

type PropsType = {
  obj?: any
}

const DrawerButton = memo<{ isOpen: boolean }>(({ isOpen }) => {
  return isOpen ? <Text className='iconfont '></Text> : <Text className='iconfont '></Text>
})

export default memo((props: PropsType) => {
  const [openDetail, setOpenDetail] = useState(false)

  const handleOpenDetail = () => {
    setOpenDetail((isOpen) => !isOpen)
  }

  const [selected, setSelect] = useState(0)

  const onSelectOrderType = (type) => {
    setSelect(type)
  }

  return (
    <LayoutBlock circle customClassName={styles.layout}>
      <MCheckbox>
        <View className='flex-row justify-between' onClick={handleOpenDetail}>
          <View className={styles.topItem}>
            <View className='flex-row'>
              <View className={styles.topTitle}>灵玉布行</View>
              <Tag type='info' size='normal'>
                刘思伟
              </Tag>
            </View>
            <View className={styles.summary}>
              <Text>已选 1 种面料，1 个颜色，共 4 条</Text>
            </View>
          </View>
          <DrawerButton isOpen={openDetail} />
        </View>
      </MCheckbox>
      <View className={styles.detailBox}>
        <View className={styles.orderType}>
          <Divider customClassName={styles.line}></Divider>
          <View className={styles.orderTypeTitle}>订单类型</View>
          <View className={styles.orderTypeDetail}>
            <NormalButton
              type={selected === 0 ? 'primary' : 'info'}
              plain={selected !== 0}
              customStyles={{ padding: '0 50rpx' }}
              circle
              onClick={() => onSelectOrderType(0)}>
              大货
            </NormalButton>
            <NormalButton
              type={selected === 1 ? 'primary' : 'info'}
              plain={selected !== 1}
              customStyles={{ padding: '0 50rpx' }}
              circle
              onClick={() => onSelectOrderType(1)}>
              散剪
            </NormalButton>
            <NormalButton
              type={selected === 2 ? 'primary' : 'info'}
              plain={selected !== 2}
              customStyles={{ padding: '0 50rpx' }}
              circle
              onClick={() => onSelectOrderType(2)}>
              剪板
            </NormalButton>
          </View>
        </View>
        <View className={styles.orderColor}>
          <Divider customClassName={styles.line}></Divider>
          <View className={classnames(styles.orderTypeTitle, 'justify-between')}>
            <Text>布料颜色</Text>
            <Tag type='danger' size='normal' circle>
              大货单位：条
            </Tag>
          </View>
        </View>
      </View>
    </LayoutBlock>
  )
})
